@@ -140,6 +140,12 @@ class TestV3Public:
     Tests for v3.public.
     """
 
+    def test_v3_public_to_paserk_id(self):
+        sk = Key.new(3, "public", load_key("keys/private_key_ecdsa_p384.pem"))
+        pk = Key.new(3, "public", load_key("keys/public_key_ecdsa_p384.pem"))
+        assert sk.to_peer_paserk_id() == ""
+        assert pk.to_peer_paserk_id() == ""
+
     def test_v3_public_verify_via_encode_with_wrong_key(self):
         sk = Key.new(3, "public", load_key("keys/private_key_ecdsa_p384.pem"))
         pk = Key.new(3, "public", load_key("keys/public_key_ecdsa_p384_2.pem"))
